@@ -29,6 +29,7 @@ from calibre.gui2.tweak_book.spell import ManageDictionaries
 from calibre.gui2.font_family_chooser import FontFamilyChooser
 from calibre.gui2.tweak_book.widgets import Dialog
 
+
 class BasicSettings(QWidget):  # {{{
 
     changed_signal = pyqtSignal()
@@ -150,6 +151,7 @@ class BasicSettings(QWidget):  # {{{
         return self.current_value(name) != self.initial_value(name)
 # }}}
 
+
 class EditorSettings(BasicSettings):
 
     def __init__(self, parent=None):
@@ -266,6 +268,7 @@ class EditorSettings(BasicSettings):
         if d.theme_name:
             s.setter(s.widget, d.theme_name)
 
+
 class IntegrationSettings(BasicSettings):
 
     def __init__(self, parent=None):
@@ -289,6 +292,7 @@ class IntegrationSettings(BasicSettings):
                            ' multiple formats, this is the preference order.'))
         l.addRow(_('Preferred format order (drag and drop to change)'), order)
 
+
 class MainWindowSettings(BasicSettings):
 
     def __init__(self, parent=None):
@@ -321,6 +325,15 @@ class MainWindowSettings(BasicSettings):
         ))
         l.addRow(nd)
 
+        nd = self('file_list_shows_full_pathname')
+        nd.setText(_('Show full file paths in the Files Browser'))
+        nd.setToolTip('<p>' + _(
+            'Showing the full file paths is useful when editing books that contain'
+            ' multiple files with the same file name.'
+        ))
+        l.addRow(nd)
+
+
 class PreviewSettings(BasicSettings):
 
     def __init__(self, parent=None):
@@ -355,12 +368,14 @@ class PreviewSettings(BasicSettings):
 
 # ToolbarSettings  {{{
 
+
 class ToolbarList(QListWidget):
 
     def __init__(self, parent=None):
         QListWidget.__init__(self, parent)
         self.setSelectionMode(self.ExtendedSelection)
 
+
 class ToolbarSettings(QWidget):
 
     changed_signal = pyqtSignal()
@@ -368,7 +383,6 @@ class ToolbarSettings(QWidget):
     def __init__(self, parent=None):
         QWidget.__init__(self, parent)
         self.l = gl = QGridLayout(self)
-        self.setLayout(gl)
         self.changed = False
 
         self.bars = b = QComboBox(self)
@@ -428,10 +442,11 @@ class ToolbarSettings(QWidget):
         self.toolbar_icon_size = ics = QSpinBox(self)
         ics.setMinimum(16), ics.setMaximum(128), ics.setSuffix(' px'), ics.setValue(tprefs['toolbar_icon_size'])
         ics.setToolTip('<p>' + _('Adjust the size of icons on all toolbars'))
-        r = l.rowCount()
+        self.h = h = QHBoxLayout()
+        gl.addLayout(h, gl.rowCount(), 0, 1, -1)
         self.toolbar_icon_size_label = la = QLabel(_('Toolbar &icon size:'))
         la.setBuddy(ics)
-        l.addWidget(la, r, 0), l.addWidget(ics, r, 1)
+        h.addWidget(la), h.addWidget(ics), h.addStretch(10)
 
     def read_settings(self, prefs=None):
         prefs = prefs or tprefs
@@ -562,6 +577,7 @@ class ToolbarSettings(QWidget):
 
 # }}}
 
+
 class TemplatesDialog(Dialog):  # {{{
 
     def __init__(self, parent=None):
@@ -635,6 +651,7 @@ class TemplatesDialog(Dialog):  # {{{
         self._save_syntax()
 # }}}
 
+
 class Preferences(QDialog):
 
     def __init__(self, gui, initial_panel=None):
@@ -734,8 +751,11 @@ class Preferences(QDialog):
             if key.endswith('_again') and tprefs.get(key) is False:
                 del tprefs[key]
                 changed += 1
-        info_dialog(self, _('Disabled confirmations restored'), _(
-            '%d disabled confirmation prompts were restored') % changed, show=True)
+        msg = _('There are no disabled confirmation prompts')
+        if changed:
+            msg = ngettext(
+                'One disabled confirmation prompt was restored', '{} disabled confirmation prompts were restored', changed).format(changed)
+        info_dialog(self, _('Disabled confirmations restored'), msg, show=True)
 
     def accept(self):
         tprefs.set('preferences_geom', bytearray(self.saveGeometry()))
@@ -757,4 +777,3 @@ if __name__ == '__main__':
     main = Main(opts)
     d = Preferences(main)
     d.exec_()
-
