@@ -14,18 +14,19 @@ Test a binary calibre build to ensure that all needed binary images/libraries ha
 
 import os, ctypes, sys, unittest
 from calibre.constants import plugins, iswindows, islinux, isosx
-is_travis = os.environ.get('TRAVIS') == 'true'
+is_ci = os.environ.get('CI', '').lower() == 'true'
+
 
 class BuildTest(unittest.TestCase):
 
-    @unittest.skipUnless(iswindows, 'DLL loading needs testing only on windows')
+    @unittest.skipUnless(iswindows and not is_ci, 'DLL loading needs testing only on windows (non-continuous integration)')
     def test_dlls(self):
         import win32api
         base = win32api.GetDllDirectory()
         for x in os.listdir(base):
             if x.lower().endswith('.dll'):
                 try:
-                    ctypes.WinDLL(os.path.join(base, x))
+                    ctypes.WinDLL(str(os.path.join(base, x)))
                 except Exception as err:
                     self.assertTrue(False, 'Failed to load DLL %s with error: %s' % (x, err))
 
@@ -60,7 +61,7 @@ class BuildTest(unittest.TestCase):
 
     def test_plugins(self):
         exclusions = set()
-        if is_travis:
+        if is_ci:
             if isosx:
                 # The compiler version on OS X is different between the
                 # machine on which the dependencies are built and the
@@ -128,7 +129,7 @@ class BuildTest(unittest.TestCase):
         fmts = set(map(unicode, QImageReader.supportedImageFormats()))
         testf = {'jpg', 'png', 'svg', 'ico', 'gif'}
         self.assertEqual(testf.intersection(fmts), testf, "Qt doesn't seem to be able to load some of its image plugins. Available plugins: %s" % fmts)
-        data = I('blank.png', allow_user_override=False, data=True)
+        data = P('images/blank.png', allow_user_override=False, data=True)
         img = image_from_data(data)
         image_from_data(P('catalog/mastheadImage.gif', allow_user_override=False, data=True))
         for fmt in 'png bmp jpeg'.split():
@@ -144,6 +145,9 @@ class BuildTest(unittest.TestCase):
         na = QNetworkAccessManager()
         self.assertTrue(hasattr(na, 'sslErrors'), 'Qt not compiled with openssl')
         from PyQt5.QtWebKitWidgets import QWebView
+        if iswindows:
+            from PyQt5.Qt import QtWin
+            QtWin
         QWebView()
         del QWebView
         del na
@@ -203,7 +207,7 @@ class BuildTest(unittest.TestCase):
         import psutil
         psutil.Process(os.getpid())
 
-    @unittest.skipIf(is_travis and isosx, 'Currently there is a C++ ABI incompatibility until the osx-build machine is moved to OS X 10.9')
+    @unittest.skipIf(is_ci and isosx, 'Currently there is a C++ ABI incompatibility until the osx-build machine is moved to OS X 10.9')
     def test_podofo(self):
         from calibre.utils.podofo import test_podofo as dotest
         dotest()
@@ -227,6 +231,7 @@ class BuildTest(unittest.TestCase):
             if not cafile or not cafile.endswith('/mozilla-ca-certs.pem') or not os.access(cafile, os.R_OK):
                 self.assert_('Mozilla CA certs not loaded')
 
+
 def find_tests():
     ans = unittest.defaultTestLoader.loadTestsFromTestCase(BuildTest)
     from calibre.utils.icu_test import find_tests
@@ -237,6 +242,7 @@ def find_tests():
     ans.addTests(find_tests())
     return ans
 
+
 def test():
     from calibre.utils.run_tests import run_cli
     run_cli(find_tests())
